---
name: Bug report
about: Create a report to help us improve Rekall
title: '[BUG] '
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Run command '...'
2. Validating State Store payload '...'
3. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**State Store Sample (Optional but highly recommended)**
If applicable, run `rekall snapshot` and provide a sanitized snippet or attach a zip of the `project-state` folder triggering the issue. Ensure NO SECRETS are included.

**Environment (please complete the following information):**
 - OS: [e.g. iOS, Windows, Ubuntu]
 - Python Version: [e.g. 3.9]
 - Rekall Version: [e.g. 0.1.0]

**Additional context**
Add any other context about the problem here.
